package com.djhk.uav.airspace.service;



import com.djhk.uav.airspace.domain.AirplaneApply;
import com.djhk.uav.airspace.domain.AirplaneApplyExport;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

public interface AirplaneService {

    /**
     * 查询空域申请
     *
     * @param id 空域申请主键
     * @return 空域申请
     */
    public AirplaneApply selectAirplaneApplyById(Long id);

    /**
     * 查询才新增申请的id
     * @return
     */
//    public Long selectAirplaneApplyId();

    /**
     * 查询空域申请列表
     *
     * @return 空域申请集合
     */
    public List<AirplaneApply> selectAirplaneApplyList(AirplaneApply airplaneApply);

    /**
     * 导出空域申请列表
     *
     * @return 导出空域申请集合
     */
    public List<AirplaneApplyExport> exportAirplaneApplyList(AirplaneApply airplaneApply);


    public void exportAirplaneApply(HttpServletResponse response, Long id) throws Exception;

    /**
     * 新增空域申请
     *
     * @param airplaneApply 空域申请
     * @return 结果
     */
    public int insertAirplaneApply(AirplaneApply airplaneApply);

    /**
     * 修改空域申请
     *
     * @param airplaneApply 空域申请
     * @return 结果
     */
    public int updateAirplaneApply(AirplaneApply airplaneApply);

    /**
     * 删除空域申请
     *
     * @param id 空域申请主键
     * @return 结果
     */
    public int deleteAirplaneApplyById(Long id);

    /**
     * 批量删除空域申请
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAirplaneApplyByIds(Long[] ids);
}
